@@ -4,11 +4,11 @@ use 5.016;
 use warnings;
 
 package Proch::N50;
-$Proch::N50::VERSION = '0.023';
+$Proch::N50::VERSION = '0.031';
 
 use File::Basename;
 use Exporter qw(import);
-our @EXPORT = qw(getStats getN50);
+our @EXPORT = qw(getStats getN50 jsonStats);
 
 
 my $hasJSON = 0;
@@ -43,7 +43,15 @@ sub getN50 {
         return 0;
     }
 }
-
+sub jsonStats {
+  my ($file) = @_;
+  my $stats = getStats($file,  'JSON');
+  if ($stats->{status} and $stats->{json}) {
+    return $stats->{json}
+  } else {
+    return undef;
+  }
+}
 sub getStats {
 
     # Parses a FASTA/FASTQ file and returns stats
@@ -159,7 +167,7 @@ Proch::N50 - Calculate N50 from a FASTA or FASTQ file without dependencies
 
 =head1 VERSION
 
-version 0.023
+version 0.031
 
 =head1 SYNOPSIS
 
@@ -260,6 +268,11 @@ name of the directory containing the input file
 
 =back
 
+=head2 jsonStats(filepath)
+
+Returns the JSON string with basic stats (same as $result->{json} from I<getStats>(File, JSON)).
+Requires JSON installed.
+
 =head1 Dependencies
 
 =over 4
